ComponentIdSet

Struct ComponentIdSet 

pub struct ComponentIdSet(/* private fields */);
A set of ComponentIds.

Implementations

Source

impl ComponentIdSet

pub const fn new() -> Self

Create a new empty ComponentIdSet.

pub fn insert(&mut self, index: ComponentId)

Adds a ComponentId to the set.

pub fn remove(&mut self, index: ComponentId)

Removes a ComponentId from the set.

pub fn clear(&mut self)

Removes all ComponentIds from the set.

pub fn contains(&self, index: ComponentId) -> bool

Returns true if the ComponentId is in the set.

pub fn is_disjoint(&self, other: &ComponentIdSet) -> bool

Returns true if self has no elements in common with other. This is equivalent to checking for an empty intersection.

pub fn is_subset(&self, other: &ComponentIdSet) -> bool

Returns true if the set is a subset of another, i.e. other contains at least all the values in self.

pub fn is_clear(&self) -> bool

Returns true if the set is empty.

pub fn iter(&self) -> ComponentIdIter<Ones<'_>>

Iterates the ComponentIds in the set.

pub fn union<'a>( &'a self, other: &'a ComponentIdSet, ) -> ComponentIdIter<Union<'a>>

Returns a lazy iterator over the union of two ComponentIdSets.

pub fn intersection<'a>( &'a self, other: &'a ComponentIdSet, ) -> ComponentIdIter<Intersection<'a>>

Returns a lazy iterator over the intersection of two ComponentIdSets.

pub fn difference<'a>( &'a self, other: &'a ComponentIdSet, ) -> ComponentIdIter<Difference<'a>>

Returns a lazy iterator over the difference of two ComponentIdSets.

pub fn union_with(&mut self, other: &ComponentIdSet)

In-place union of two ComponentIdSets.

pub fn intersect_with(&mut self, other: &ComponentIdSet)

In-place intersection of two ComponentIdSets.

pub fn difference_with(&mut self, other: &ComponentIdSet)

In-place difference of two ComponentIdSets.

pub fn difference_from(&mut self, other: &ComponentIdSet)

In-place reversed difference of two ComponentIdSets. This sets self to be other.difference(self).