pub struct QuerySortedIter<'w, 's, D: QueryData, F: QueryFilter, I>{ /* private fields */ }Expand description
An Iterator over sorted query results of a Query.
This struct is created by the QueryIter::sort, QueryIter::sort_unstable,
QueryIter::sort_by, QueryIter::sort_unstable_by, QueryIter::sort_by_key,
QueryIter::sort_unstable_by_key, and QueryIter::sort_by_cached_key methods.
Implementations
Sourceimpl<'w, 's, D: QueryData, F: QueryFilter, I> QuerySortedIter<'w, 's, D, F, I>
impl<'w, 's, D: QueryData, F: QueryFilter, I> QuerySortedIter<'w, 's, D, F, I>
Sourcepub fn fetch_next(&mut self) -> Option<D::Item<'_, 's>>
pub fn fetch_next(&mut self) -> Option<D::Item<'_, 's>>
Get the next result from the query.
If the QueryData does not implement IterQueryData,
then it is not sound to yield multiple items concurrently
and the resulting QuerySortedIter will not implement Iterator.
In that case, this method can be used to iterate over the items
while ensuring only one is alive at a time.
Most queries do implement IterQueryData,
and can use the ordinary Iterator::next
method or a for loop.
Example
fn system(mut query: Query<&mut C>) {
let mut iter = query.iter_mut().sort::<&C>();
while let Some(mut c) = iter.fetch_next() {
//
}
}Sourcepub fn fetch_next_back(&mut self) -> Option<D::Item<'_, 's>>where
I: DoubleEndedIterator,
pub fn fetch_next_back(&mut self) -> Option<D::Item<'_, 's>>where
I: DoubleEndedIterator,
Get the next result from the back of the query.
If the QueryData does not implement IterQueryData,
then it is not sound to yield multiple items concurrently
and the resulting QuerySortedIter will not implement Iterator.
In that case, this method can be used to iterate over the items
while ensuring only one is alive at a time.
Most queries do implement IterQueryData,
and can use the ordinary Iterator::next
method or a for loop.